@@ -15,6 +15,7 @@
 #' @param prepend_var_lab logical. Should we prepend variable label before value
 #'   labels? By default we will add variable labels to value labels only if
 #'   \code{x} or predictor is list (several variables).
+#' @param stat_lab character. Labels for the frequency columns. 
 #'
 #' @return object of class 'etable'. Basically it's a data.frame but class
 #'   is needed for custom methods.
@@ -64,23 +65,32 @@
 #' fre(list(score, brands))
 #' 
 #' @export
-fre = function(x, weight = NULL, drop_unused_labels = TRUE, prepend_var_lab = FALSE){
+fre = function(x, 
+               weight = NULL, 
+               drop_unused_labels = TRUE, 
+               prepend_var_lab = FALSE, 
+               stat_lab = getOption("expss.fre_stat_lab", c("Count", "Valid percent", "Percent", "Responses, %", "Cumulative responses, %"))){
     UseMethod("fre")
 }
 
 #' @export
-fre.list = function(x, weight = NULL, drop_unused_labels = TRUE, prepend_var_lab = TRUE){
+fre.list = function(x, 
+                    weight = NULL, 
+                    drop_unused_labels = TRUE, 
+                    prepend_var_lab = TRUE, 
+                    stat_lab = getOption("expss.fre_stat_lab", c("Count", "Valid percent", "Percent", "Responses, %", "Cumulative responses, %"))){
     x = flat_list(x, flat_df = FALSE)
     res = lapply(x, fre, 
                  weight = weight, 
                  drop_unused_labels = drop_unused_labels, 
-                 prepend_var_lab = prepend_var_lab
+                 prepend_var_lab = prepend_var_lab,
+                 stat_lab = stat_lab
                  )
     do.call(add_rows, res)
 }
 
 #' @export
-fre.default = function(x, weight = NULL, drop_unused_labels = TRUE, prepend_var_lab = FALSE){
+fre.default = function(x, weight = NULL, drop_unused_labels = TRUE, prepend_var_lab = FALSE, stat_lab = getOption("expss.fre_stat_lab", c("Count", "Valid percent", "Percent", "Responses, %", "Cumulative responses, %"))){
     str_x = expr_to_character(substitute(x))
     if(is.null(x)){
         stop(paste0(str_x," is NULL. Perhaps a variable does not exist."))
@@ -170,10 +180,7 @@ fre.default = function(x, weight = NULL, drop_unused_labels = TRUE, prepend_var_
         first_column_label = if_null(varlab, str_x)
     }
     res[[1]] = remove_unnecessary_splitters(res[[1]]) 
-    colnames(res) = c(first_column_label, 
-                      "Count", "Valid percent", 
-                      "Percent", "Responses, %",
-                      "Cumulative responses, %")
+    colnames(res) = c(first_column_label, stat_lab)
     
     class(res) = union("etable", class(res))
     res
